==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/inputs/GetScriptPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.inputs

import com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the Kusto cluster.
 * @property databaseName The name of the database in the Kusto cluster.
 * @property resourceGroupName The name of the resource group containing the Kusto cluster.
 * @property scriptName The name of the Kusto database script.
 */
public data class GetScriptPlainArgs(
    public val clusterName: String,
    public val databaseName: String,
    public val resourceGroupName: String,
    public val scriptName: String,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs =
        com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .databaseName(databaseName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .scriptName(scriptName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetScriptPlainArgs].
 */
@PulumiTagMarker
public class GetScriptPlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var databaseName: String? = null

    private var resourceGroupName: String? = null

    private var scriptName: String? = null

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("ycoelmujafemjbpm")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the database in the Kusto cluster.
     */
    @JvmName("hnfpchkbpocqmlom")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("ayrttwomtptmyvos")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Kusto database script.
     */
    @JvmName("qmddihbjfkgdnayd")
    public suspend fun scriptName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scriptName = mapped
    }

    internal fun build(): GetScriptPlainArgs = GetScriptPlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        scriptName = scriptName ?: throw PulumiNullFieldException("scriptName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/kusto/kotlin/inputs/GetScriptPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.kusto.kotlin.inputs

import com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property clusterName The name of the Kusto cluster.
 * @property databaseName The name of the database in the Kusto cluster.
 * @property resourceGroupName The name of the resource group containing the Kusto cluster.
 * @property scriptName The name of the Kusto database script.
 */
public data class GetScriptPlainArgs(
    public val clusterName: String,
    public val databaseName: String,
    public val resourceGroupName: String,
    public val scriptName: String,
) : ConvertibleToJava<com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs =
        com.pulumi.azurenative.kusto.inputs.GetScriptPlainArgs.builder()
            .clusterName(clusterName.let({ args0 -> args0 }))
            .databaseName(databaseName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .scriptName(scriptName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetScriptPlainArgs].
 */
@PulumiTagMarker
public class GetScriptPlainArgsBuilder internal constructor() {
    private var clusterName: String? = null

    private var databaseName: String? = null

    private var resourceGroupName: String? = null

    private var scriptName: String? = null

    /**
     * @param value The name of the Kusto cluster.
     */
    @JvmName("pfblnaxsicannaos")
    public suspend fun clusterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.clusterName = mapped
    }

    /**
     * @param value The name of the database in the Kusto cluster.
     */
    @JvmName("oxecujufjaommokm")
    public suspend fun databaseName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group containing the Kusto cluster.
     */
    @JvmName("wdwpjtcidcncjmpt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Kusto database script.
     */
    @JvmName("mgtsgqukfdmvugot")
    public suspend fun scriptName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scriptName = mapped
    }

    internal fun build(): GetScriptPlainArgs = GetScriptPlainArgs(
        clusterName = clusterName ?: throw PulumiNullFieldException("clusterName"),
        databaseName = databaseName ?: throw PulumiNullFieldException("databaseName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        scriptName = scriptName ?: throw PulumiNullFieldException("scriptName"),
    )
}
